summaryrefslogtreecommitdiffstats
path: root/chalk/ui/squeezedcombobox.h
diff options
context:
space:
mode:
Diffstat (limited to 'chalk/ui/squeezedcombobox.h')
-rw-r--r--chalk/ui/squeezedcombobox.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/chalk/ui/squeezedcombobox.h b/chalk/ui/squeezedcombobox.h
index 03a1cdb9..50f4bc77 100644
--- a/chalk/ui/squeezedcombobox.h
+++ b/chalk/ui/squeezedcombobox.h
@@ -117,9 +117,9 @@ public:
TQString itemHighlighted( );
/**
* Sets the tqsizeHint() of this widget.
*/
- virtual TQSize tqsizeHint() const;
+ virtual TQSize sizeHint() const;
private slots:
void slotTimeOut();
@@ -117,9 +117,9 @@ public:
TQString itemHighlighted( );
/**
- * Sets the tqsizeHint() of this widget.
+ * Sets the sizeHint() of this widget.
*/